@@ -49,87 +49,87 @@ class testcase_ulist(unittest.TestCase):
         """tests constructor"""
 
         c = C([1, 2, 3, 3, 4, 5, 5])
-        self.assertEquals([1, 2, 3, 4, 5], c)
+        self.assertEqual([1, 2, 3, 4, 5], c)
 
         c = C(['one', 'two', 'three', 'one'])
-        self.assertEquals(['one', 'two', 'three'], c)
+        self.assertEqual(['one', 'two', 'three'], c)
 
     def testcase_ulist_add(self):
         """tests l=l+other"""
 
         seed = [1, 2, 3]
         c = C(seed)
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c = c + []
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c = c + 4
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c = c + 4
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c = c + 'word'
-        self.assertEquals(seed + [4] + ['word'], c)
+        self.assertEqual(seed + [4] + ['word'], c)
 
         seed = ['one', 'two', 'three']
         c = C(seed)
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c = c + ['four', 'five']
-        self.assertEquals(seed + ['four', 'five'], c)
+        self.assertEqual(seed + ['four', 'five'], c)
 
     def testcase_ulist_iadd(self):
         """tests l+=other"""
 
         seed = [1, 2, 3]
         c = C(seed)
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c += []
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c += 4
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c += 4
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c += [4, 3, 2, 1]
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c += 'word'
-        self.assertEquals(seed + [4] + ['word'], c)
+        self.assertEqual(seed + [4] + ['word'], c)
 
         seed = ['one', 'two', 'three']
         c = C(seed)
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         c += ['four', 'five']
-        self.assertEquals(seed + ['four', 'five'], c)
+        self.assertEqual(seed + ['four', 'five'], c)
 
     def testcase_ulist_radd(self):
         """tests l=other+l"""
 
         seed = [1, 2, 3]
         c = C(seed)
-        self.assertEquals(seed, c)
+        self.assertEqual(seed, c)
 
         l = [] + c
-        self.assertEquals(seed, l)
+        self.assertEqual(seed, l)
 
         l = [3] + c
-        self.assertEquals(seed, c)
-        self.assertEquals(seed, l)
+        self.assertEqual(seed, c)
+        self.assertEqual(seed, l)
 
         l = [3, 3, 4, 4] + c
-        self.assertEquals(seed, c)
-        self.assertEquals(seed + [4], l)
+        self.assertEqual(seed, c)
+        self.assertEqual(seed + [4], l)
 
         l = [4] + ['word'] + c
-        self.assertEquals(seed, c)
-        self.assertEquals(seed + [4] + ['word'], l)
+        self.assertEqual(seed, c)
+        self.assertEqual(seed + [4] + ['word'], l)
 
     def testcase_ulist_append(self):
 
@@ -137,13 +137,13 @@ class testcase_ulist(unittest.TestCase):
         c = C(seed)
 
         c.append(4)
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c.append(4)
-        self.assertEquals(seed + [4], c)
+        self.assertEqual(seed + [4], c)
 
         c.append('word')
-        self.assertEquals(seed + [4] + ['word'], c)
+        self.assertEqual(seed + [4] + ['word'], c)
 
     def testcase_ulist_insert(self):
 
@@ -151,10 +151,10 @@ class testcase_ulist(unittest.TestCase):
         c = C(seed)
 
         c.insert(0, 0)
-        self.assertEquals([0] + seed, c)
+        self.assertEqual([0] + seed, c)
 
         c.insert(1, 0)
-        self.assertEquals([0] + seed, c)
+        self.assertEqual([0] + seed, c)
 
     def testcase_ulist_pop(self):
 
@@ -162,10 +162,10 @@ class testcase_ulist(unittest.TestCase):
         c = C(seed)
 
         c.pop()
-        self.assertEquals(c, [1, 2])
+        self.assertEqual(c, [1, 2])
 
         c.pop(1)
-        self.assertEquals(c, [1])
+        self.assertEqual(c, [1])
 
     def testcase_ulist_remove(self):
 
@@ -173,10 +173,10 @@ class testcase_ulist(unittest.TestCase):
         c = C(seed)
 
         c.remove(2)
-        self.assertEquals(c, [1, 3])
+        self.assertEqual(c, [1, 3])
 
         c.remove(1)
-        self.assertEquals(c, [3])
+        self.assertEqual(c, [3])
 
 
 def suite():
