@@ -29,7 +29,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import unittest
 from smartcard.scard import *
-import sys
 
 
 class testcase_returncodes(unittest.TestCase):
@@ -99,7 +98,7 @@ class testcase_returncodes(unittest.TestCase):
             SCARD_W_CARD_NOT_AUTHENTICATED,
             )
         #for e in errors:
-        #    print hex((e+0x100000000) & 0xFFFFFFFF)
+        #    print(hex((e+0x100000000) & 0xFFFFFFFF), SCardGetErrorMessage(e))
 
 
 def suite():
